
'''
This file is automatically generated; Do not edit it. :)
'''
IS_FINAL = True
VERSION = '39.3.1'
BRANCH_NICK = 'release-39.3.1'
REVISION_ID = '4178a1ccf1a0768c53c5ab465dc4c98e4206c552'
REVNO = '14309'
